@@ -1,9 +1,9 @@
 package Test::Smoke;
 use strict;
 
-# $Id: Smoke.pm 1055 2007-08-11 11:32:32Z abeltje $
+# $Id: Smoke.pm 1173 2008-04-18 17:54:26Z abeltje $
 use vars qw( $VERSION $REVISION $conf @EXPORT );
-$VERSION  = '1.20';
+$VERSION  = '1.31';
 $REVISION = __get_ts_patchlevel();
 
 use base 'Exporter';
@@ -154,8 +154,13 @@ sub run_smoke {
     $conf->{v} && $conf->{defaultenv} and
         $smoker->tty( "Running smoke tests without \$ENV{PERLIO}\n" );
 
-    $conf->{v} && $conf->{harnessonly} and
-        $smoker->tty( "Running smoke tests only with harness.\n" );
+    my $harness_msg;
+    if ( $conf->{harnessonly} ) {
+        $harness_msg = "Running test suite only with 'harness'";
+        $conf->{harness3opts} and
+            $harness_msg .= " with HARNESS_OPTIONS=$conf->{harness3opts}";
+    }
+    $conf->{v} && $harness_msg and $smoker->tty( "$harness_msg.\n" );
 
     chdir $conf->{ddir} or die "Cannot chdir($conf->{ddir}): $!";
     unless ( $continue ) {
@@ -196,7 +201,7 @@ use FindBin;
 use File::Spec::Functions;
 
 sub __get_ts_patchlevel {
-    my( $rev ) = q$Rev: 1055 $ =~ /(\d+)/;
+    my( $rev ) = q$Rev: 1173 $ =~ /(\d+)/;
     my $dotpatch = catfile $FindBin::Bin, '.patch';
     local *DOTPATCH;
     open DOTPATCH, "< $dotpatch" or return $rev;
@@ -211,7 +216,7 @@ sub __get_ts_patchlevel {
 
 =head1 REVISION
 
-$Id: Smoke.pm 1055 2007-08-11 11:32:32Z abeltje $
+$Id: Smoke.pm 1173 2008-04-18 17:54:26Z abeltje $
 
 =head1 COPYRIGHT
 
