@@ -1,9 +1,9 @@
 package Test::Smoke::SysInfo;
 use strict;
 
-# $Id: SysInfo.pm 1026 2007-03-09 14:14:35Z abeltje $
+# $Id: SysInfo.pm 1155 2008-01-03 13:32:28Z abeltje $
 use vars qw( $VERSION @EXPORT_OK );
-$VERSION = '0.036';
+$VERSION = '0.039';
 
 use base 'Exporter';
 @EXPORT_OK = qw( &sysinfo &tsuname );
@@ -399,16 +399,34 @@ sub Darwin {
     $system_profiler{$1} = $2
 	while $system_profiler_output =~ m/^\s*([\w ]+):\s+(.+)$/gm;
 
+    # convert newer output from Intel core duo
+    my %keymap = (
+        'Processor Name'       => 'CPU Type',
+        'Processor Speed'      => 'CPU Speed',
+        'Model Name'           => 'Machine Name',
+        'Model Identifier'     => 'Machine Model',
+        'Number Of Processors' => 'Number Of CPUs',
+    );
+    for my $newkey ( keys %keymap ) {
+        my $oldkey = $keymap{ $newkey };
+        exists $system_profiler{ $newkey} and
+            $system_profiler{ $oldkey } = delete $system_profiler{ $newkey };
+    }
+
     $system_profiler{'CPU Type'} =~ s/PowerPC\s*(\w+).*/macppc$1/;
     $system_profiler{'CPU Speed'} =~ 
-	s/(\d+(?:\.\d+)?)\s*GHz/sprintf("%d MHz", $1 * 1000)/e;
+	s/(0(?:\.\d+)?)\s*GHz/sprintf("%d MHz", $1 * 1000)/e;
 
     my $model = $system_profiler{'Machine Name'} ||
                 $system_profiler{'Machine Model'};
+
+    my $ncpu = $system_profiler{'Number Of CPUs'};
+    $system_profiler{'Total Number Of Cores'} and
+        $ncpu .= " ($system_profiler{'Total Number Of Cores'} cores";
     return {
         _cpu_type => ($system_profiler{'CPU Type'} || __get_cpu_type()),
         _cpu      => ("$model ($system_profiler{'CPU Speed'})" || __get_cpu),
-        _ncpu     => $system_profiler{'Number Of CPUs'},
+        _ncpu     => $ncpu,
         _host     => __get_hostname(),
         _os       => __get_os() . " (Mac OS X)",
     };
@@ -480,6 +498,12 @@ sub Linux {
             ( $_ => __from_proc_cpuinfo( $_, \@cpu_info ) );
         } @parts;
         $cpu = sprintf "%s (%s %.0fMHz)", map $info{ $_ } => @parts;
+
+        my $ncores = 0;
+        for my $cores ( grep /cpu cores\s*:\d+/ => @cpu_info ) {
+            $ncores += $cores =~ /(\d+)/ ? $1 : 0;
+        }
+        $ncores and $ncpu .= " ($ncores cores)";
     } else {
         $cpu = __get_cpu();
     }
@@ -713,6 +737,8 @@ version. Takes almost the same arguments:
 =cut
 
 sub tsuname {
+    my $si;
+    ref $_[0] eq __PACKAGE__ and $si = shift;
     my @args = map split() => @_;
 
     my @sw = qw( n s m c p );
@@ -725,7 +751,7 @@ sub tsuname {
     my %show = map +( $_ => undef ) => grep exists $sw{ $_ } => @args;
     @args = grep exists $show{ $_ } => @sw;
 
-    my $si = Test::Smoke::SysInfo->new;
+    defined $si or $si = Test::Smoke::SysInfo->new;
     return join " ", @{ $si }{ @sw{ @args } };
 }
 
@@ -741,7 +767,7 @@ L<Test::Smoke::Smoker>, L<Test::Smoke::Reporter>
 
 With contributions from Jarkko Hietaniemi, Merijn Brand, Campo
 Weijerman, Alan Burlison, Allen Smith, Alain Barbet, Dominic Dunlop,
-Rich Rauenzahn.
+Rich Rauenzahn, David Cantrell.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
